@@ -25,7 +25,6 @@
 #include <errno.h>
 #include <locale.h>
 #include <stdlib.h>
-#include <time.h>
 #include <unistd.h>
 
 #include <glib.h>
@@ -244,6 +243,7 @@ bus_acquired_cb (GDBusConnection *connection,
 		method_call_cb,
 		NULL,
 		NULL,
+		{ 0 }
 	};
 
 	OwnData *data = (OwnData *) user_data;
@@ -291,7 +291,6 @@ name_acquired_cb (GDBusConnection *connection,
 		g_assert_not_reached ();
 	}
 
-
 	if (!terminal_app_handle_options (terminal_app_get (), data->options, TRUE /* do resume */, &error))
 	{
 		g_printerr ("Failed to handle options: %s\n", error->message);
@@ -526,7 +525,8 @@ main (int argc, char **argv)
 
 	if (options->startup_id == NULL)
 	{
-		options->startup_id = g_strdup_printf ("_TIME%lu", g_get_monotonic_time () / 1000);
+		options->startup_id = g_strdup_printf ("_TIME%" G_GINT64_FORMAT,
+		                                       g_get_monotonic_time () / 1000);
 	}
 
 	gdk_init (&argc, &argv);
